summaryrefslogtreecommitdiffstats
path: root/include/ap_slotmem.h
diff options
context:
space:
mode:
authorStefan Fritsch <sf@apache.org>2012-01-02 05:17:46 +0100
committerStefan Fritsch <sf@apache.org>2012-01-02 05:17:46 +0100
commitc77318c46eca5a0ea97023f89810eed2f18a2e72 (patch)
tree3eaf2e76a5ad04e630b71cfca441fade45065efd /include/ap_slotmem.h
parentDisplay registered providers (diff)
downloadapache2-c77318c46eca5a0ea97023f89810eed2f18a2e72.tar.xz
apache2-c77318c46eca5a0ea97023f89810eed2f18a2e72.zip
Avoid using C++ reserved word 'new' in arg name in header
Doc tweaks git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@1226339 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/ap_slotmem.h')
-rw-r--r--include/ap_slotmem.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/include/ap_slotmem.h b/include/ap_slotmem.h
index 6d69bdd303..496f455e69 100644
--- a/include/ap_slotmem.h
+++ b/include/ap_slotmem.h
@@ -70,7 +70,7 @@ typedef unsigned int ap_slotmem_type_t;
typedef struct ap_slotmem_instance_t ap_slotmem_instance_t;
/**
- * callback function used for slotmem.
+ * callback function used for slotmem doall.
* @param mem is the memory associated with a worker.
* @param data is what is passed to slotmem.
* @param pool is pool used
@@ -95,24 +95,26 @@ struct ap_slotmem_provider_t {
/**
* create a new slotmem with each item size is item_size.
* This would create shared memory, basically.
* @param name is a key used for debugging and in mod_status output or allow another process to share this space.
* @param item_size size of each item
* @param item_num number of item to create.
* @param type type of slotmem.
* @param pool is pool used
* @return APR_SUCCESS if all went well
*/
- apr_status_t (* create)(ap_slotmem_instance_t **new, const char *name, apr_size_t item_size, unsigned int item_num, ap_slotmem_type_t type, apr_pool_t *pool);
+ apr_status_t (* create)(ap_slotmem_instance_t **inst, const char *name, apr_size_t item_size, unsigned int item_num, ap_slotmem_type_t type, apr_pool_t *pool);
/**
* attach to an existing slotmem.
* This would attach to shared memory, basically.
* @param name is a key used for debugging and in mod_status output or allow another process to share this space.
* @param item_size size of each item
* @param item_num max number of item.
* @param pool is pool to memory allocate.
* @return APR_SUCCESS if all went well
*/
- apr_status_t (* attach)(ap_slotmem_instance_t **new, const char *name, apr_size_t *item_size, unsigned int *item_num, apr_pool_t *pool);
+ apr_status_t (* attach)(ap_slotmem_instance_t **inst, const char *name, apr_size_t *item_size, unsigned int *item_num, apr_pool_t *pool);
/**
* get the memory ptr associated with this worker slot.
* @param s ap_slotmem_instance_t to use.
@@ -95,24 +95,26 @@ struct ap_slotmem_provider_t {
* create a new slotmem with each item size is item_size.
* This would create shared memory, basically.
- * @param name is a key used for debugging and in mod_status output or allow another process to share this space.
+ * @param inst where to store pointer to slotmem
+ * @param name a key used for debugging and in mod_status output or allow another process to share this space.
* @param item_size size of each item
* @param item_num number of item to create.
@@ -95,24 +95,26 @@ struct ap_slotmem_provider_t {
* attach to an existing slotmem.
* This would attach to shared memory, basically.
- * @param name is a key used for debugging and in mod_status output or allow another process to share this space.
+ * @param inst where to store pointer to slotmem
+ * @param name a key used for debugging and in mod_status output or allow another process to share this space.
* @param item_size size of each item
* @param item_num max number of item.